1.0.0 API documentation: GLM_GTX_normal

| 1.0.0 API documentation

Functions
GLM_GTX_normal
Experimental extensions

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | triangleNormal (vec< 3, T, Q > const &p1, vec< 3, T, Q > const &p2, vec< 3, T, Q > const &p3)
| Computes triangle normal from triangle points. More...

## Detailed Description

Include <glm/gtx/normal.hpp> to use the features of this extension.

Compute the normal of a triangle.

## Function Documentation

## ◆ triangleNormal()

GLM_FUNC_DECL vec<3, T, Q> glm::triangleNormal | ( | vec< 3, T, Q > const & | p1,
|  | vec< 3, T, Q > const & | p2,
|  | vec< 3, T, Q > const & | p3
| ) |  |

Computes triangle normal from triangle points.

See also
  GLM_GTX_normal